# Application Portfolio Management Onboarding Dashboard for Enterprise Architects
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/application-portfolio-management-onboarding-dashboard-for-enterprise-architects#overview)
  * [Dashboard Versions](https://help.sap.com/docs/leanix/ea/application-portfolio-management-onboarding-dashboard-for-enterprise-architects#dashboard-versions)
  * [Activating the Dashboard](https://help.sap.com/docs/leanix/ea/application-portfolio-management-onboarding-dashboard-for-enterprise-architects#activating-the-dashboard)
  * [Updating the Dashboard](https://help.sap.com/docs/leanix/ea/application-portfolio-management-onboarding-dashboard-for-enterprise-architects#updating-the-dashboard)
  * [Understanding Best-Practice Metrics](https://help.sap.com/docs/leanix/ea/application-portfolio-management-onboarding-dashboard-for-enterprise-architects#understanding-best-practice-metrics)


The Application Portfolio Management Onboarding Dashboard for enterprise architects streamlines the process of onboarding to SAP LeanIX Application Portfolio Management.
